==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/ParametrSystemowy.java <==
package pl.topteam.dps.model.main_gen;

import java.math.BigDecimal;
import java.util.Date;
import pl.topteam.dps.enums.TypParametruSystemowego;
import pl.topteam.dps.generic.GenericDPSObject;

public abstract class ParametrSystemowy extends GenericDPSObject {
    /**
     * PARAMETR_SYSTEMOWY.ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long id;

    /**
     * PARAMETR_SYSTEMOWY.SLOWO_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long slowoId;

    /**
     * PARAMETR_SYSTEMOWY.TYP
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private TypParametruSystemowego typ;

    /**
     * PARAMETR_SYSTEMOWY.DATA_OD
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Date dataOd;

    /**
     * PARAMETR_SYSTEMOWY.DATA_DO
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Date dataDo;

    /**
     * PARAMETR_SYSTEMOWY.WARTOSC_B
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Boolean wartoscB;

    /**
     * PARAMETR_SYSTEMOWY.WARTOSC_D
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private BigDecimal wartoscD;

    /**
     * PARAMETR_SYSTEMOWY.WARTOSC_I
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Integer wartoscI;

    /**
     * PARAMETR_SYSTEMOWY.WARTOSC_S
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String wartoscS;

    /**
     * PARAMETR_SYSTEMOWY.UKRYTY
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Boolean ukryty;

    /**
     * PARAMETR_SYSTEMOWY.KOLEJNOSC
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Integer kolejnosc;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return PARAMETR_SYSTEMOWY.ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * PARAMETR_SYSTEMOWY.ID
     *
     * @param id
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return PARAMETR_SYSTEMOWY.SLOWO_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getSlowoId() {
        return slowoId;
    }

    /**
     * PARAMETR_SYSTEMOWY.SLOWO_ID
     *
     * @param slowoId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setSlowoId(Long slowoId) {
        this.slowoId = slowoId;
    }

    /**
     * @return PARAMETR_SYSTEMOWY.TYP
     * @mbggenerated 2014-03-10 10:45:37
     */
    public TypParametruSystemowego getTyp() {
        return typ;
    }

    /**
     * PARAMETR_SYSTEMOWY.TYP
     *
     * @param typ
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setTyp(TypParametruSystemowego typ) {
        this.typ = typ;
    }

    /**
     * @return PARAMETR_SYSTEMOWY.DATA_OD
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Date getDataOd() {
        return dataOd;
    }

    /**
     * PARAMETR_SYSTEMOWY.DATA_OD
     *
     * @param dataOd
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setDataOd(Date dataOd) {
        this.dataOd = dataOd;
    }

    /**
     * @return PARAMETR_SYSTEMOWY.DATA_DO
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Date getDataDo() {
        return dataDo;
    }

    /**
     * PARAMETR_SYSTEMOWY.DATA_DO
     *
     * @param dataDo
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setDataDo(Date dataDo) {
        this.dataDo = dataDo;
    }

    /**
     * @return PARAMETR_SYSTEMOWY.WARTOSC_B
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Boolean getWartoscB() {
        return wartoscB;
    }

    /**
     * PARAMETR_SYSTEMOWY.WARTOSC_B
     *
     * @param wartoscB
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setWartoscB(Boolean wartoscB) {
        this.wartoscB = wartoscB;
    }

    /**
     * @return PARAMETR_SYSTEMOWY.WARTOSC_D
     * @mbggenerated 2014-03-10 10:45:37
     */
    public BigDecimal getWartoscD() {
        return wartoscD;
    }

    /**
     * PARAMETR_SYSTEMOWY.WARTOSC_D
     *
     * @param wartoscD
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setWartoscD(BigDecimal wartoscD) {
        this.wartoscD = wartoscD;
    }

    /**
     * @return PARAMETR_SYSTEMOWY.WARTOSC_I
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Integer getWartoscI() {
        return wartoscI;
    }

    /**
     * PARAMETR_SYSTEMOWY.WARTOSC_I
     *
     * @param wartoscI
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setWartoscI(Integer wartoscI) {
        this.wartoscI = wartoscI;
    }

    /**
     * @return PARAMETR_SYSTEMOWY.WARTOSC_S
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getWartoscS() {
        return wartoscS;
    }

    /**
     * PARAMETR_SYSTEMOWY.WARTOSC_S
     *
     * @param wartoscS
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setWartoscS(String wartoscS) {
        this.wartoscS = wartoscS == null ? null : wartoscS.trim();
    }

    /**
     * @return PARAMETR_SYSTEMOWY.UKRYTY
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Boolean getUkryty() {
        return ukryty;
    }

    /**
     * PARAMETR_SYSTEMOWY.UKRYTY
     *
     * @param ukryty
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setUkryty(Boolean ukryty) {
        this.ukryty = ukryty;
    }

    /**
     * @return PARAMETR_SYSTEMOWY.KOLEJNOSC
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Integer getKolejnosc() {
        return kolejnosc;
    }

    /**
     * PARAMETR_SYSTEMOWY.KOLEJNOSC
     *
     * @param kolejnosc
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setKolejnosc(Integer kolejnosc) {
        this.kolejnosc = kolejnosc;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        ParametrSystemowy other = (ParametrSystemowy) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getSlowoId() == null ? other.getSlowoId() == null : this.getSlowoId().equals(other.getSlowoId()))
            && (this.getTyp() == null ? other.getTyp() == null : this.getTyp().equals(other.getTyp()))
            && (this.getDataOd() == null ? other.getDataOd() == null : this.getDataOd().equals(other.getDataOd()))
            && (this.getDataDo() == null ? other.getDataDo() == null : this.getDataDo().equals(other.getDataDo()))
            && (this.getWartoscB() == null ? other.getWartoscB() == null : this.getWartoscB().equals(other.getWartoscB()))
            && (this.getWartoscD() == null ? other.getWartoscD() == null : this.getWartoscD().equals(other.getWartoscD()))
            && (this.getWartoscI() == null ? other.getWartoscI() == null : this.getWartoscI().equals(other.getWartoscI()))
            && (this.getWartoscS() == null ? other.getWartoscS() == null : this.getWartoscS().equals(other.getWartoscS()))
            && (this.getUkryty() == null ? other.getUkryty() == null : this.getUkryty().equals(other.getUkryty()))
            && (this.getKolejnosc() == null ? other.getKolejnosc() == null : this.getKolejnosc().equals(other.getKolejnosc()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getSlowoId() == null) ? 0 : getSlowoId().hashCode());
        result = prime * result + ((getTyp() == null) ? 0 : getTyp().hashCode());
        result = prime * result + ((getDataOd() == null) ? 0 : getDataOd().hashCode());
        result = prime * result + ((getDataDo() == null) ? 0 : getDataDo().hashCode());
        result = prime * result + ((getWartoscB() == null) ? 0 : getWartoscB().hashCode());
        result = prime * result + ((getWartoscD() == null) ? 0 : getWartoscD().hashCode());
        result = prime * result + ((getWartoscI() == null) ? 0 : getWartoscI().hashCode());
        result = prime * result + ((getWartoscS() == null) ? 0 : getWartoscS().hashCode());
        result = prime * result + ((getUkryty() == null) ? 0 : getUkryty().hashCode());
        result = prime * result + ((getKolejnosc() == null) ? 0 : getKolejnosc().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", slowoId=").append(slowoId);
        sb.append(", typ=").append(typ);
        sb.append(", dataOd=").append(dataOd);
        sb.append(", dataDo=").append(dataDo);
        sb.append(", wartoscB=").append(wartoscB);
        sb.append(", wartoscD=").append(wartoscD);
        sb.append(", wartoscI=").append(wartoscI);
        sb.append(", wartoscS=").append(wartoscS);
        sb.append(", ukryty=").append(ukryty);
        sb.append(", kolejnosc=").append(kolejnosc);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/ParametrSystemowy.java <==
package pl.topteam.dps.model.main_gen;

import java.math.BigDecimal;
import java.util.Date;
import pl.topteam.dps.enums.TypParametruSystemowego;
import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class ParametrSystemowy extends GenericDPSObject {
    /**
     * PARAMETR_SYSTEMOWY.ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long id;

    /**
     * PARAMETR_SYSTEMOWY.SLOWO_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long slowoId;

    /**
     * PARAMETR_SYSTEMOWY.TYP
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private TypParametruSystemowego typ;

    /**
     * PARAMETR_SYSTEMOWY.DATA_OD
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Date dataOd;

    /**
     * PARAMETR_SYSTEMOWY.DATA_DO
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Date dataDo;

    /**
     * PARAMETR_SYSTEMOWY.WARTOSC_B
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Boolean wartoscB;

    /**
     * PARAMETR_SYSTEMOWY.WARTOSC_D
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private BigDecimal wartoscD;

    /**
     * PARAMETR_SYSTEMOWY.WARTOSC_I
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Integer wartoscI;

    /**
     * PARAMETR_SYSTEMOWY.WARTOSC_S
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String wartoscS;

    /**
     * PARAMETR_SYSTEMOWY.UKRYTY
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Boolean ukryty;

    /**
     * PARAMETR_SYSTEMOWY.KOLEJNOSC
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Integer kolejnosc;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return PARAMETR_SYSTEMOWY.ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * PARAMETR_SYSTEMOWY.ID
     *
     * @param id
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return PARAMETR_SYSTEMOWY.SLOWO_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getSlowoId() {
        return slowoId;
    }

    /**
     * PARAMETR_SYSTEMOWY.SLOWO_ID
     *
     * @param slowoId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setSlowoId(Long slowoId) {
        this.slowoId = slowoId;
    }

    /**
     * @return PARAMETR_SYSTEMOWY.TYP
     * @mbggenerated 2014-03-13 16:02:38
     */
    public TypParametruSystemowego getTyp() {
        return typ;
    }

    /**
     * PARAMETR_SYSTEMOWY.TYP
     *
     * @param typ
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setTyp(TypParametruSystemowego typ) {
        this.typ = typ;
    }

    /**
     * @return PARAMETR_SYSTEMOWY.DATA_OD
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Date getDataOd() {
        return dataOd;
    }

    /**
     * PARAMETR_SYSTEMOWY.DATA_OD
     *
     * @param dataOd
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setDataOd(Date dataOd) {
        this.dataOd = dataOd;
    }

    /**
     * @return PARAMETR_SYSTEMOWY.DATA_DO
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Date getDataDo() {
        return dataDo;
    }

    /**
     * PARAMETR_SYSTEMOWY.DATA_DO
     *
     * @param dataDo
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setDataDo(Date dataDo) {
        this.dataDo = dataDo;
    }

    /**
     * @return PARAMETR_SYSTEMOWY.WARTOSC_B
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Boolean getWartoscB() {
        return wartoscB;
    }

    /**
     * PARAMETR_SYSTEMOWY.WARTOSC_B
     *
     * @param wartoscB
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setWartoscB(Boolean wartoscB) {
        this.wartoscB = wartoscB;
    }

    /**
     * @return PARAMETR_SYSTEMOWY.WARTOSC_D
     * @mbggenerated 2014-03-13 16:02:38
     */
    public BigDecimal getWartoscD() {
        return wartoscD;
    }

    /**
     * PARAMETR_SYSTEMOWY.WARTOSC_D
     *
     * @param wartoscD
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setWartoscD(BigDecimal wartoscD) {
        this.wartoscD = wartoscD;
    }

    /**
     * @return PARAMETR_SYSTEMOWY.WARTOSC_I
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Integer getWartoscI() {
        return wartoscI;
    }

    /**
     * PARAMETR_SYSTEMOWY.WARTOSC_I
     *
     * @param wartoscI
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setWartoscI(Integer wartoscI) {
        this.wartoscI = wartoscI;
    }

    /**
     * @return PARAMETR_SYSTEMOWY.WARTOSC_S
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getWartoscS() {
        return wartoscS;
    }

    /**
     * PARAMETR_SYSTEMOWY.WARTOSC_S
     *
     * @param wartoscS
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setWartoscS(String wartoscS) {
        this.wartoscS = wartoscS == null ? null : wartoscS.trim();
    }

    /**
     * @return PARAMETR_SYSTEMOWY.UKRYTY
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Boolean getUkryty() {
        return ukryty;
    }

    /**
     * PARAMETR_SYSTEMOWY.UKRYTY
     *
     * @param ukryty
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setUkryty(Boolean ukryty) {
        this.ukryty = ukryty;
    }

    /**
     * @return PARAMETR_SYSTEMOWY.KOLEJNOSC
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Integer getKolejnosc() {
        return kolejnosc;
    }

    /**
     * PARAMETR_SYSTEMOWY.KOLEJNOSC
     *
     * @param kolejnosc
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setKolejnosc(Integer kolejnosc) {
        this.kolejnosc = kolejnosc;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        ParametrSystemowy other = (ParametrSystemowy) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getSlowoId() == null ? other.getSlowoId() == null : this.getSlowoId().equals(other.getSlowoId()))
            && (this.getTyp() == null ? other.getTyp() == null : this.getTyp().equals(other.getTyp()))
            && (this.getDataOd() == null ? other.getDataOd() == null : this.getDataOd().equals(other.getDataOd()))
            && (this.getDataDo() == null ? other.getDataDo() == null : this.getDataDo().equals(other.getDataDo()))
            && (this.getWartoscB() == null ? other.getWartoscB() == null : this.getWartoscB().equals(other.getWartoscB()))
            && (this.getWartoscD() == null ? other.getWartoscD() == null : this.getWartoscD().equals(other.getWartoscD()))
            && (this.getWartoscI() == null ? other.getWartoscI() == null : this.getWartoscI().equals(other.getWartoscI()))
            && (this.getWartoscS() == null ? other.getWartoscS() == null : this.getWartoscS().equals(other.getWartoscS()))
            && (this.getUkryty() == null ? other.getUkryty() == null : this.getUkryty().equals(other.getUkryty()))
            && (this.getKolejnosc() == null ? other.getKolejnosc() == null : this.getKolejnosc().equals(other.getKolejnosc()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getSlowoId() == null) ? 0 : getSlowoId().hashCode());
        result = prime * result + ((getTyp() == null) ? 0 : getTyp().hashCode());
        result = prime * result + ((getDataOd() == null) ? 0 : getDataOd().hashCode());
        result = prime * result + ((getDataDo() == null) ? 0 : getDataDo().hashCode());
        result = prime * result + ((getWartoscB() == null) ? 0 : getWartoscB().hashCode());
        result = prime * result + ((getWartoscD() == null) ? 0 : getWartoscD().hashCode());
        result = prime * result + ((getWartoscI() == null) ? 0 : getWartoscI().hashCode());
        result = prime * result + ((getWartoscS() == null) ? 0 : getWartoscS().hashCode());
        result = prime * result + ((getUkryty() == null) ? 0 : getUkryty().hashCode());
        result = prime * result + ((getKolejnosc() == null) ? 0 : getKolejnosc().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", slowoId=").append(slowoId);
        sb.append(", typ=").append(typ);
        sb.append(", dataOd=").append(dataOd);
        sb.append(", dataDo=").append(dataDo);
        sb.append(", wartoscB=").append(wartoscB);
        sb.append(", wartoscD=").append(wartoscD);
        sb.append(", wartoscI=").append(wartoscI);
        sb.append(", wartoscS=").append(wartoscS);
        sb.append(", ukryty=").append(ukryty);
        sb.append(", kolejnosc=").append(kolejnosc);
        sb.append("]");
        return sb.toString();
    }
}
